@@ -88,7 +88,8 @@ class MissingInitError(UploadFailureError):
   def __init__(self, package_dir):
     super(MissingInitError, self).__init__(textwrap.dedent("""\
         [{}] is not a valid Python package because it does not contain an \
-        `__init__.py` file. Please create one and try again.
+        `__init__.py` file. Please create one and try again. Also, please \
+        ensure that --package-path refers to a local directory.
         """).format(package_dir))
 
 
@@ -445,7 +446,7 @@ def BuildPackages(package_path, output_dir):
     try:
       return _RunSetupTools(package_root, setup_py_path, output_dir)
     except RuntimeError as err:
-      raise SetuptoolsFailedError(str(err), generated)
+      raise SetuptoolsFailedError(six.text_type(err), generated)
     finally:
       if generated:
         # For some reason, this artifact gets generated in the package root by
