@@ -44,7 +44,8 @@ def _DetailedHelp():
 
 def _AddArgs(parser, include_alpha_logging, include_l7_internal_load_balancing,
              include_private_ipv6_access_alpha,
-             include_private_ipv6_access_beta, include_aggregate_purpose):
+             include_private_ipv6_access_beta, include_private_ipv6_access_v1,
+             include_aggregate_purpose):
   """Add subnetwork create arguments to parser."""
   parser.display_info.AddFormat(flags.DEFAULT_LIST_FORMAT)
 
@@ -89,8 +90,8 @@ def _AddArgs(parser, include_alpha_logging, include_l7_internal_load_balancing,
       '--enable-flow-logs',
       action='store_true',
       default=None,
-      help=('Enable/disable VPC flow logging for this subnet. More information '
-            'for VPC flow logs can be found at '
+      help=('Enable/disable VPC Flow Logs for this subnet. More information '
+            'for VPC Flow Logs can be found at '
             'https://cloud.google.com/vpc/docs/using-flow-logs.'))
 
   flags.AddLoggingAggregationInterval(parser, messages)
@@ -98,13 +99,31 @@ def _AddArgs(parser, include_alpha_logging, include_l7_internal_load_balancing,
       '--logging-flow-sampling',
       type=arg_parsers.BoundedFloat(lower_bound=0.0, upper_bound=1.0),
       help="""\
-      Can only be specified if VPC flow logging for this subnetwork is
+      Can only be specified if VPC Flow Logs for this subnetwork is
       enabled. The value of the field must be in [0, 1]. Set the sampling rate
       of VPC flow logs within the subnetwork where 1.0 means all collected
       logs are reported and 0.0 means no logs are reported. Default is 0.5
       which means half of all collected logs are reported.
       """)
 
+  parser.add_argument(
+      '--logging-filter-expr',
+      help="""\
+        Can only be specified if VPC Flow Logs for this subnetwork is enabled.
+        Export filter used to define which logs should be generated.
+        """)
+  flags.AddLoggingMetadata(parser, messages)
+  parser.add_argument(
+      '--logging-metadata-fields',
+      type=arg_parsers.ArgList(),
+      metavar='METADATA_FIELD',
+      default=None,
+      help="""\
+      Can only be specified if VPC Flow Logs for this subnetwork is enabled
+      and "metadata" is set to CUSTOM_METADATA. The comma-separated list of
+      metadata fields that should be added to reported logs.
+      """)
+
   if include_alpha_logging:
     messages = apis.GetMessagesModule('compute',
                                       compute_api.COMPUTE_ALPHA_API_VERSION)
@@ -121,26 +140,6 @@ def _AddArgs(parser, include_alpha_logging, include_l7_internal_load_balancing,
         """)
     flags.AddLoggingMetadataDeprecated(parser, messages)
 
-    parser.add_argument(
-        '--logging-filter-expr',
-        help="""\
-        Can only be specified if VPC flow logs for this subnetwork is enabled.
-        Export filter used to define which VPC flow logs should be logged.
-        """)
-    flags.AddLoggingMetadataAlpha(parser, messages)
-    parser.add_argument(
-        '--logging-metadata-fields',
-        type=arg_parsers.ArgList(),
-        metavar='METADATA_FIELD',
-        default=None,
-        help="""\
-        Can only be specified if VPC flow logs for this subnetwork is enabled
-        and "metadata" is set to CUSTOM_METADATA. The custom list of metadata
-        fields that should be added to reported VPC flow logs.
-        """)
-  else:
-    flags.AddLoggingMetadata(parser, messages)
-
   purpose_choices = {
       'PRIVATE':
           'Regular user created or automatically created subnet.',
@@ -204,8 +203,13 @@ def _AddArgs(parser, include_alpha_logging, include_l7_internal_load_balancing,
   elif include_private_ipv6_access_beta:
     messages = apis.GetMessagesModule('compute',
                                       compute_api.COMPUTE_BETA_API_VERSION)
-    GetPrivateIpv6GoogleAccessTypeFlagMapperBeta(
-        messages).choice_arg.AddToParser(parser)
+    GetPrivateIpv6GoogleAccessTypeFlagMapper(messages).choice_arg.AddToParser(
+        parser)
+  elif include_private_ipv6_access_v1:
+    messages = apis.GetMessagesModule('compute',
+                                      compute_api.COMPUTE_GA_API_VERSION)
+    GetPrivateIpv6GoogleAccessTypeFlagMapper(messages).choice_arg.AddToParser(
+        parser)
 
   parser.display_info.AddCacheUpdater(network_flags.NetworksCompleter)
 
@@ -228,7 +232,7 @@ def GetPrivateIpv6GoogleAccessTypeFlagMapperAlpha(messages):
   )
 
 
-def GetPrivateIpv6GoogleAccessTypeFlagMapperBeta(messages):
+def GetPrivateIpv6GoogleAccessTypeFlagMapper(messages):
   return arg_utils.ChoiceEnumMapper(
       '--private-ipv6-google-access-type',
       messages.Subnetwork.PrivateIpv6GoogleAccessValueValuesEnum,
@@ -247,7 +251,6 @@ def GetPrivateIpv6GoogleAccessTypeFlagMapperBeta(messages):
 def _CreateSubnetwork(messages, subnet_ref, network_ref, args,
                       include_alpha_logging, include_l7_internal_load_balancing,
                       include_private_ipv6_access_alpha,
-                      include_private_ipv6_access_beta,
                       include_aggregate_purpose):
   """Create the subnet resource."""
   subnetwork = messages.Subnetwork(
@@ -261,8 +264,8 @@ def _CreateSubnetwork(messages, subnet_ref, network_ref, args,
       args.logging_aggregation_interval is not None or
       args.logging_flow_sampling is not None or
       args.logging_metadata is not None or
-      (include_alpha_logging and args.logging_filter_expr is not None) or
-      (include_alpha_logging and args.logging_metadata_fields is not None)):
+      args.logging_filter_expr is not None or
+      args.logging_metadata_fields is not None):
     log_config = messages.SubnetworkLogConfig(enable=args.enable_flow_logs)
     if args.logging_aggregation_interval:
       log_config.aggregationInterval = flags.GetLoggingAggregationIntervalArg(
@@ -270,15 +273,11 @@ def _CreateSubnetwork(messages, subnet_ref, network_ref, args,
     if args.logging_flow_sampling is not None:
       log_config.flowSampling = args.logging_flow_sampling
     if args.logging_metadata:
-      if include_alpha_logging:
-        log_config.metadata = flags.GetLoggingMetadataArgAlpha(
-            messages).GetEnumForChoice(args.logging_metadata)
-      else:
-        log_config.metadata = flags.GetLoggingMetadataArg(
-            messages).GetEnumForChoice(args.logging_metadata)
-    if include_alpha_logging and args.logging_filter_expr is not None:
+      log_config.metadata = flags.GetLoggingMetadataArg(
+          messages).GetEnumForChoice(args.logging_metadata)
+    if args.logging_filter_expr is not None:
       log_config.filterExpr = args.logging_filter_expr
-    if include_alpha_logging and args.logging_metadata_fields is not None:
+    if args.logging_metadata_fields is not None:
       log_config.metadataFields = args.logging_metadata_fields
     subnetwork.logConfig = log_config
 
@@ -341,18 +340,17 @@ def _CreateSubnetwork(messages, subnet_ref, network_ref, args,
     if args.private_ipv6_google_access_service_accounts is not None:
       subnetwork.privateIpv6GoogleAccessServiceAccounts = (
           args.private_ipv6_google_access_service_accounts)
-  elif include_private_ipv6_access_beta:
-    if args.private_ipv6_google_access_type is not None:
-      subnetwork.privateIpv6GoogleAccess = (
-          flags.GetPrivateIpv6GoogleAccessTypeFlagMapperBeta(
-              messages).GetEnumForChoice(args.private_ipv6_google_access_type))
+  elif args.private_ipv6_google_access_type is not None:
+    subnetwork.privateIpv6GoogleAccess = (
+        flags.GetPrivateIpv6GoogleAccessTypeFlagMapper(
+            messages).GetEnumForChoice(args.private_ipv6_google_access_type))
 
   return subnetwork
 
 
 def _Run(args, holder, include_alpha_logging,
          include_l7_internal_load_balancing, include_private_ipv6_access_alpha,
-         include_private_ipv6_access_beta, include_aggregate_purpose):
+         include_aggregate_purpose):
   """Issues a list of requests necessary for adding a subnetwork."""
   client = holder.client
 
@@ -368,7 +366,6 @@ def _Run(args, holder, include_alpha_logging,
                                  include_alpha_logging,
                                  include_l7_internal_load_balancing,
                                  include_private_ipv6_access_alpha,
-                                 include_private_ipv6_access_beta,
                                  include_aggregate_purpose)
   request = client.messages.ComputeSubnetworksInsertRequest(
       subnetwork=subnetwork,
@@ -397,6 +394,7 @@ class Create(base.CreateCommand):
   _include_l7_internal_load_balancing = True
   _include_private_ipv6_access_alpha = False
   _include_private_ipv6_access_beta = False
+  _include_private_ipv6_access_v1 = True
   _include_aggregate_purpose = False
 
   detailed_help = _DetailedHelp()
@@ -407,6 +405,7 @@ class Create(base.CreateCommand):
              cls._include_l7_internal_load_balancing,
              cls._include_private_ipv6_access_alpha,
              cls._include_private_ipv6_access_beta,
+             cls._include_private_ipv6_access_v1,
              cls._include_aggregate_purpose)
 
   def Run(self, args):
@@ -415,7 +414,6 @@ class Create(base.CreateCommand):
     return _Run(args, holder, self._include_alpha_logging,
                 self._include_l7_internal_load_balancing,
                 self._include_private_ipv6_access_alpha,
-                self._include_private_ipv6_access_beta,
                 self._include_aggregate_purpose)
 
 
