@@ -33,6 +33,7 @@ class Update(base.UpdateCommand):
   _include_l7_internal_load_balancing = True
   _include_private_ipv6_access_alpha = False
   _include_private_ipv6_access_beta = False
+  _include_private_ipv6_access_v1 = True
 
   @classmethod
   def Args(cls, parser):
@@ -47,7 +48,8 @@ class Update(base.UpdateCommand):
     flags.AddUpdateArgs(parser, cls._include_alpha_logging,
                         cls._include_l7_internal_load_balancing,
                         cls._include_private_ipv6_access_alpha,
-                        cls._include_private_ipv6_access_beta)
+                        cls._include_private_ipv6_access_beta,
+                        cls._include_private_ipv6_access_v1)
 
   def Run(self, args):
     """Issues requests necessary to update Subnetworks."""
@@ -58,8 +60,8 @@ class Update(base.UpdateCommand):
     aggregation_interval = args.logging_aggregation_interval
     flow_sampling = args.logging_flow_sampling
     metadata = args.logging_metadata
-    filter_expr = None
-    metadata_fields = None
+    filter_expr = args.logging_filter_expr
+    metadata_fields = args.logging_metadata_fields
 
     if self._include_alpha_logging:
       if args.aggregation_interval is not None:
@@ -68,10 +70,6 @@ class Update(base.UpdateCommand):
         flow_sampling = args.flow_sampling
       if args.metadata is not None:
         metadata = args.metadata
-      if args.logging_filter_expr is not None:
-        filter_expr = args.logging_filter_expr
-      if args.logging_metadata_fields is not None:
-        metadata_fields = args.logging_metadata_fields
 
     set_role_active = None
     drain_timeout_seconds = None
@@ -81,20 +79,16 @@ class Update(base.UpdateCommand):
         set_role_active = getattr(args, 'role', None) == 'ACTIVE'
 
     enable_private_ipv6_access = None
-    private_ipv6_google_access_type = None
     private_ipv6_google_access_service_accounts = None
     if self._include_private_ipv6_access_alpha:
       enable_private_ipv6_access = args.enable_private_ipv6_access
-      private_ipv6_google_access_type = args.private_ipv6_google_access_type
       private_ipv6_google_access_service_accounts = (
           args.private_ipv6_google_access_service_accounts)
-    elif self._include_private_ipv6_access_beta:
-      private_ipv6_google_access_type = args.private_ipv6_google_access_type
+    private_ipv6_google_access_type = args.private_ipv6_google_access_type
 
     return subnets_utils.MakeSubnetworkUpdateRequest(
         client,
         subnet_ref,
-        self._include_alpha_logging,
         enable_private_ip_google_access=args.enable_private_ip_google_access,
         add_secondary_ranges=args.add_secondary_ranges,
         remove_secondary_ranges=args.remove_secondary_ranges,
