@@ -45,14 +45,14 @@ class Delete(base.DeleteCommand):
   def Run(self, args):
     """Delete a Cloud Filestore instance."""
     instance_ref = args.CONCEPTS.instance.Parse()
-    delete_warning = ('You are about to delete Cloud Filestore instance {}. '
+    delete_warning = ('You are about to delete Cloud Filestore instance {}.\n'
                       'Are you sure?'.format(instance_ref.RelativeName()))
     if not console_io.PromptContinue(message=delete_warning):
       return None
     client = filestore_client.FilestoreClient(version=self._API_VERSION)
     result = client.DeleteInstance(
-        instance_ref, args.async)
-    if args.async:
+        instance_ref, args.async_)
+    if args.async_:
       command = properties.VALUES.metrics.command_name.Get().split('.')
       if command:
         command[-1] = 'list'
